# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.4.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class VersionResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current': 'str',
        'next': 'str',
        'next_since_height': 'int',
        'querier': 'str'
    }

    attribute_map = {
        'current': 'current',
        'next': 'next',
        'next_since_height': 'next_since_height',
        'querier': 'querier'
    }

    def __init__(self, current=None, next=None, next_since_height=None, querier=None):  # noqa: E501
        """VersionResponse - a model defined in Swagger"""  # noqa: E501
        self._current = None
        self._next = None
        self._next_since_height = None
        self._querier = None
        self.discriminator = None
        self.current = current
        self.next = next
        if next_since_height is not None:
            self.next_since_height = next_since_height
        self.querier = querier

    @property
    def current(self):
        """Gets the current of this VersionResponse.  # noqa: E501

        current version  # noqa: E501

        :return: The current of this VersionResponse.  # noqa: E501
        :rtype: str
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this VersionResponse.

        current version  # noqa: E501

        :param current: The current of this VersionResponse.  # noqa: E501
        :type: str
        """
        if current is None:
            raise ValueError("Invalid value for `current`, must not be `None`")  # noqa: E501

        self._current = current

    @property
    def next(self):
        """Gets the next of this VersionResponse.  # noqa: E501

        next version (minimum version for a node to become Active)  # noqa: E501

        :return: The next of this VersionResponse.  # noqa: E501
        :rtype: str
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this VersionResponse.

        next version (minimum version for a node to become Active)  # noqa: E501

        :param next: The next of this VersionResponse.  # noqa: E501
        :type: str
        """
        if next is None:
            raise ValueError("Invalid value for `next`, must not be `None`")  # noqa: E501

        self._next = next

    @property
    def next_since_height(self):
        """Gets the next_since_height of this VersionResponse.  # noqa: E501

        height at which the minimum joining version last changed  # noqa: E501

        :return: The next_since_height of this VersionResponse.  # noqa: E501
        :rtype: int
        """
        return self._next_since_height

    @next_since_height.setter
    def next_since_height(self, next_since_height):
        """Sets the next_since_height of this VersionResponse.

        height at which the minimum joining version last changed  # noqa: E501

        :param next_since_height: The next_since_height of this VersionResponse.  # noqa: E501
        :type: int
        """

        self._next_since_height = next_since_height

    @property
    def querier(self):
        """Gets the querier of this VersionResponse.  # noqa: E501

        querier version  # noqa: E501

        :return: The querier of this VersionResponse.  # noqa: E501
        :rtype: str
        """
        return self._querier

    @querier.setter
    def querier(self, querier):
        """Sets the querier of this VersionResponse.

        querier version  # noqa: E501

        :param querier: The querier of this VersionResponse.  # noqa: E501
        :type: str
        """
        if querier is None:
            raise ValueError("Invalid value for `querier`, must not be `None`")  # noqa: E501

        self._querier = querier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VersionResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.4.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DerivedPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'status': 'str',
        'decimals': 'int',
        'balance_asset': 'str',
        'balance_rune': 'str',
        'derived_depth_bps': 'str'
    }

    attribute_map = {
        'asset': 'asset',
        'status': 'status',
        'decimals': 'decimals',
        'balance_asset': 'balance_asset',
        'balance_rune': 'balance_rune',
        'derived_depth_bps': 'derived_depth_bps'
    }

    def __init__(self, asset=None, status=None, decimals=None, balance_asset=None, balance_rune=None, derived_depth_bps=None):  # noqa: E501
        """DerivedPool - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._status = None
        self._decimals = None
        self._balance_asset = None
        self._balance_rune = None
        self._derived_depth_bps = None
        self.discriminator = None
        self.asset = asset
        self.status = status
        if decimals is not None:
            self.decimals = decimals
        self.balance_asset = balance_asset
        self.balance_rune = balance_rune
        self.derived_depth_bps = derived_depth_bps

    @property
    def asset(self):
        """Gets the asset of this DerivedPool.  # noqa: E501


        :return: The asset of this DerivedPool.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this DerivedPool.


        :param asset: The asset of this DerivedPool.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def status(self):
        """Gets the status of this DerivedPool.  # noqa: E501


        :return: The status of this DerivedPool.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DerivedPool.


        :param status: The status of this DerivedPool.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def decimals(self):
        """Gets the decimals of this DerivedPool.  # noqa: E501


        :return: The decimals of this DerivedPool.  # noqa: E501
        :rtype: int
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this DerivedPool.


        :param decimals: The decimals of this DerivedPool.  # noqa: E501
        :type: int
        """

        self._decimals = decimals

    @property
    def balance_asset(self):
        """Gets the balance_asset of this DerivedPool.  # noqa: E501


        :return: The balance_asset of this DerivedPool.  # noqa: E501
        :rtype: str
        """
        return self._balance_asset

    @balance_asset.setter
    def balance_asset(self, balance_asset):
        """Sets the balance_asset of this DerivedPool.


        :param balance_asset: The balance_asset of this DerivedPool.  # noqa: E501
        :type: str
        """
        if balance_asset is None:
            raise ValueError("Invalid value for `balance_asset`, must not be `None`")  # noqa: E501

        self._balance_asset = balance_asset

    @property
    def balance_rune(self):
        """Gets the balance_rune of this DerivedPool.  # noqa: E501


        :return: The balance_rune of this DerivedPool.  # noqa: E501
        :rtype: str
        """
        return self._balance_rune

    @balance_rune.setter
    def balance_rune(self, balance_rune):
        """Sets the balance_rune of this DerivedPool.


        :param balance_rune: The balance_rune of this DerivedPool.  # noqa: E501
        :type: str
        """
        if balance_rune is None:
            raise ValueError("Invalid value for `balance_rune`, must not be `None`")  # noqa: E501

        self._balance_rune = balance_rune

    @property
    def derived_depth_bps(self):
        """Gets the derived_depth_bps of this DerivedPool.  # noqa: E501

        the depth of the derived virtual pool relative to L1 pool (in basis points)  # noqa: E501

        :return: The derived_depth_bps of this DerivedPool.  # noqa: E501
        :rtype: str
        """
        return self._derived_depth_bps

    @derived_depth_bps.setter
    def derived_depth_bps(self, derived_depth_bps):
        """Sets the derived_depth_bps of this DerivedPool.

        the depth of the derived virtual pool relative to L1 pool (in basis points)  # noqa: E501

        :param derived_depth_bps: The derived_depth_bps of this DerivedPool.  # noqa: E501
        :type: str
        """
        if derived_depth_bps is None:
            raise ValueError("Invalid value for `derived_depth_bps`, must not be `None`")  # noqa: E501

        self._derived_depth_bps = derived_depth_bps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DerivedPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DerivedPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.4.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Thorname(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'expire_block_height': 'int',
        'owner': 'str',
        'preferred_asset': 'str',
        'preferred_asset_swap_threshold_rune': 'str',
        'affiliate_collector_rune': 'str',
        'aliases': 'list[ThornameAlias]'
    }

    attribute_map = {
        'name': 'name',
        'expire_block_height': 'expire_block_height',
        'owner': 'owner',
        'preferred_asset': 'preferred_asset',
        'preferred_asset_swap_threshold_rune': 'preferred_asset_swap_threshold_rune',
        'affiliate_collector_rune': 'affiliate_collector_rune',
        'aliases': 'aliases'
    }

    def __init__(self, name=None, expire_block_height=None, owner=None, preferred_asset=None, preferred_asset_swap_threshold_rune=None, affiliate_collector_rune=None, aliases=None):  # noqa: E501
        """Thorname - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._expire_block_height = None
        self._owner = None
        self._preferred_asset = None
        self._preferred_asset_swap_threshold_rune = None
        self._affiliate_collector_rune = None
        self._aliases = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if expire_block_height is not None:
            self.expire_block_height = expire_block_height
        if owner is not None:
            self.owner = owner
        self.preferred_asset = preferred_asset
        if preferred_asset_swap_threshold_rune is not None:
            self.preferred_asset_swap_threshold_rune = preferred_asset_swap_threshold_rune
        if affiliate_collector_rune is not None:
            self.affiliate_collector_rune = affiliate_collector_rune
        self.aliases = aliases

    @property
    def name(self):
        """Gets the name of this Thorname.  # noqa: E501


        :return: The name of this Thorname.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Thorname.


        :param name: The name of this Thorname.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def expire_block_height(self):
        """Gets the expire_block_height of this Thorname.  # noqa: E501


        :return: The expire_block_height of this Thorname.  # noqa: E501
        :rtype: int
        """
        return self._expire_block_height

    @expire_block_height.setter
    def expire_block_height(self, expire_block_height):
        """Sets the expire_block_height of this Thorname.


        :param expire_block_height: The expire_block_height of this Thorname.  # noqa: E501
        :type: int
        """

        self._expire_block_height = expire_block_height

    @property
    def owner(self):
        """Gets the owner of this Thorname.  # noqa: E501


        :return: The owner of this Thorname.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this Thorname.


        :param owner: The owner of this Thorname.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def preferred_asset(self):
        """Gets the preferred_asset of this Thorname.  # noqa: E501


        :return: The preferred_asset of this Thorname.  # noqa: E501
        :rtype: str
        """
        return self._preferred_asset

    @preferred_asset.setter
    def preferred_asset(self, preferred_asset):
        """Sets the preferred_asset of this Thorname.


        :param preferred_asset: The preferred_asset of this Thorname.  # noqa: E501
        :type: str
        """
        if preferred_asset is None:
            raise ValueError("Invalid value for `preferred_asset`, must not be `None`")  # noqa: E501

        self._preferred_asset = preferred_asset

    @property
    def preferred_asset_swap_threshold_rune(self):
        """Gets the preferred_asset_swap_threshold_rune of this Thorname.  # noqa: E501

        Amount of RUNE currently needed to trigger a preferred asset swap.  # noqa: E501

        :return: The preferred_asset_swap_threshold_rune of this Thorname.  # noqa: E501
        :rtype: str
        """
        return self._preferred_asset_swap_threshold_rune

    @preferred_asset_swap_threshold_rune.setter
    def preferred_asset_swap_threshold_rune(self, preferred_asset_swap_threshold_rune):
        """Sets the preferred_asset_swap_threshold_rune of this Thorname.

        Amount of RUNE currently needed to trigger a preferred asset swap.  # noqa: E501

        :param preferred_asset_swap_threshold_rune: The preferred_asset_swap_threshold_rune of this Thorname.  # noqa: E501
        :type: str
        """

        self._preferred_asset_swap_threshold_rune = preferred_asset_swap_threshold_rune

    @property
    def affiliate_collector_rune(self):
        """Gets the affiliate_collector_rune of this Thorname.  # noqa: E501

        Amount of RUNE currently accrued by this thorname in affiliate fees waiting to be swapped to preferred asset.  # noqa: E501

        :return: The affiliate_collector_rune of this Thorname.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_collector_rune

    @affiliate_collector_rune.setter
    def affiliate_collector_rune(self, affiliate_collector_rune):
        """Sets the affiliate_collector_rune of this Thorname.

        Amount of RUNE currently accrued by this thorname in affiliate fees waiting to be swapped to preferred asset.  # noqa: E501

        :param affiliate_collector_rune: The affiliate_collector_rune of this Thorname.  # noqa: E501
        :type: str
        """

        self._affiliate_collector_rune = affiliate_collector_rune

    @property
    def aliases(self):
        """Gets the aliases of this Thorname.  # noqa: E501


        :return: The aliases of this Thorname.  # noqa: E501
        :rtype: list[ThornameAlias]
        """
        return self._aliases

    @aliases.setter
    def aliases(self, aliases):
        """Sets the aliases of this Thorname.


        :param aliases: The aliases of this Thorname.  # noqa: E501
        :type: list[ThornameAlias]
        """
        if aliases is None:
            raise ValueError("Invalid value for `aliases`, must not be `None`")  # noqa: E501

        self._aliases = aliases

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Thorname, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Thorname):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.4.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class VaultRouter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chain': 'str',
        'router': 'str'
    }

    attribute_map = {
        'chain': 'chain',
        'router': 'router'
    }

    def __init__(self, chain=None, router=None):  # noqa: E501
        """VaultRouter - a model defined in Swagger"""  # noqa: E501
        self._chain = None
        self._router = None
        self.discriminator = None
        if chain is not None:
            self.chain = chain
        if router is not None:
            self.router = router

    @property
    def chain(self):
        """Gets the chain of this VaultRouter.  # noqa: E501


        :return: The chain of this VaultRouter.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this VaultRouter.


        :param chain: The chain of this VaultRouter.  # noqa: E501
        :type: str
        """

        self._chain = chain

    @property
    def router(self):
        """Gets the router of this VaultRouter.  # noqa: E501


        :return: The router of this VaultRouter.  # noqa: E501
        :rtype: str
        """
        return self._router

    @router.setter
    def router(self, router):
        """Sets the router of this VaultRouter.


        :param router: The router of this VaultRouter.  # noqa: E501
        :type: str
        """

        self._router = router

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VaultRouter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VaultRouter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
